mean_var_score — skchange

Skip to main content
`Ctrl`+`K`

# mean_var_score

mean_var_score(precomputed_params: ndarray, starts: ndarray, ends: ndarray, splits: ndarray) → ndarray

  Calculate the score for a change in the mean and/or variance.

  Computes the likelihood ratio test for a change in the mean and/or variance of i.i.d. Gaussian data.

  Parameters:
    precomputed_paramsnp.ndarray

      Precomputed parameters from init_mean_var_score.

    startsnp.ndarray

      Start indices of the intervals to test for a change in the mean.

    endsnp.ndarray

      End indices of the intervals to test for a change in the mean.

    splitsnp.ndarray

      Split indices of the intervals to test for a change in the mean.

  Returns:
    scorenp.ndarray

      Scores for a difference in the mean or variance at the given intervals and splits.

  Notes

  To optimize performance, no checks are performed on (starts, splits, ends).